/**
   Bojan Nikolic <b.nikolic@mrao.cam.ac.uk>, <bojan@bnikolic.co.uk>
   Initial version November 2010. 
   
   This file is part of LibAIR and is licensed under GNU Public
   License Version 2
   
   \file hdfutils.cpp
*/

#include <boost/format.hpp>      

#include "hdfutils.hpp"
#include "hdferrors.hpp"

namespace hd5 {

  void write(hid_t fout,
	     const std::string &group,
	     const std::vector<double> &d)
  {
    hsize_t dims[1];
    dims[0]= d.size();
    herr_t e=H5LTmake_dataset_double(fout, 
				     group.c_str(), 
				     1, 
				     dims, 
				     &d[0]);
    if (e)
    {
      throw HDF5Error("unkown", "Could not write dataset");
    }
  }

  void write(hid_t fout,
	     const std::string &group,
	     size_t d1, 
	     size_t d2, 
	     const std::vector<double> &d)
  {
    hsize_t dims[2];
    dims[0]= d1;
    dims[1]= d2;
    herr_t e=H5LTmake_dataset_double(fout, 
				     group.c_str(), 
				     2, 
				     dims, 
				     &d[0]);
    if (e)
    {
      throw HDF5Error("unkown", "Could not write dataset");
    }
  }

  void write(hid_t fout,
	     const std::string &group,
	     size_t d1, 
	     size_t d2, 
	     size_t d3, 
	     const std::vector<double> &d)
  {
    write(fout, group,
	  d1, d2, d3,
	  &d[0]);
  }

  void write(hid_t fout,
	     const std::string &group,
	     size_t d1, 
	     size_t d2, 
	     const double *d)
  {
    hsize_t dims[2];
    dims[0]= d1;
    dims[1]= d2;
    herr_t e=H5LTmake_dataset_double(fout, 
				     group.c_str(), 
				     2, 
				     dims, 
				     d);
    if (e)
    {
      throw HDF5Error("unkown", "Could not write dataset");
    }
  }

  void write(hid_t fout,
	     const std::string &group,
	     size_t d1, 
	     size_t d2, 
	     size_t d3, 
	     const double *d)
  {
    hsize_t dims[3];
    dims[0]= d1;
    dims[1]= d2;
    dims[2]= d3;
    herr_t e=H5LTmake_dataset_double(fout, 
				     group.c_str(), 
				     3, 
				     dims, 
				     d);
    if (e)
    {
      throw HDF5Error("unkown", "Could not write dataset");
    }
  }

  void write(hid_t fout,
	     const std::string &group,
	     const std::vector<int> &d)
  {
    hsize_t dims[1];
    dims[0]= d.size();
    herr_t e=H5LTmake_dataset_int(fout, 
				  group.c_str(), 
				  1, 
				  dims, 
				  &d[0]);
    if (e)
    {
      throw HDF5Error("unkown", "Could not write dataset");
    }
  }

  void writeAtt(hid_t fout,
		const std::string &group,
		const std::string &prefix,
		const std::map<size_t, std::string> &m)
  {
    for(std::map<size_t, std::string>::const_iterator i=m.begin();
	i!=m.end();
	++i)
    {

      std::string 
	aname((boost::format("%s%i") % prefix % i->first).str());
      herr_t e=H5LTset_attribute_string(fout,
					group.c_str(), 
					aname.c_str(),
					i->second.c_str());
    if (e)
    {
      throw HDF5Error("unkown", "Could not write dataset");
    }
    }
  }
}


