/**
   Bojan Nikolic <b.nikolic@mrao.cam.ac.uk>, <bojan@bnikolic.co.uk>
   Initial version November 2010. 
   
   This file is part of LibAIR and is licensed under GNU Public
   License Version 2
   
   \file resoutput.cpp

*/

#include <iostream>
#include <boost/multi_array.hpp>
#include <hdf5.h>
#include <hdf5_hl.h>
#include <H5Fpublic.h>

#include "resoutput.hpp"

#include "../src/apps/arraygains.hpp"


namespace LibAIR {

  void writeAntPath(const ArrayGains& g,
		    const std::string &fnameout)
  {
    hid_t fout=H5Fcreate(fnameout.c_str(), 
			 H5F_ACC_TRUNC,
			 NULL, NULL);
    hsize_t dims[2];
    dims[0]=g.g_time().size();
    dims[1]=g.nAnt+1;

    boost::multi_array<double, 2> buffer(boost::extents[dims[0]][dims[1]]);
    
    if(buffer.shape()[0]==0)
      throw std::runtime_error("No rows to write in output gain table?");      

    if (g.g_path().shape()[0] != buffer.shape()[0] or
	g.g_path().shape()[1] != (buffer.shape()[1]-1) )
    {
      throw std::runtime_error("Error: unexpected missmatch in array shapes");
    }

    for (size_t j=0; j<dims[0]; ++j)
    {
      buffer[j][0]=g.g_time()[j];
      for (size_t i=0; i<g.nAnt; ++i)
      {
	const double path=g.g_path()[j][i];
	buffer[j][1+i]=path;
      }
    }
    
    herr_t e=H5LTmake_dataset_double(fout, 
				     "WVRPath", 
				     2, 
				     dims, 
				     &buffer[0][0]);
    if (e)
    {
      std::cerr<<"Warning: error writing WVR paths to HDF5";
    }

    H5Fclose(fout);
    
  }


}


